unit BMForm;

// (c) Copyright 1999, Dipl. Ing. Mike Lischke (public@lischke-online.de)

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Types3DS, StdCtrls, ExtCtrls;

type
  TBitmapForm = class(TForm)
    GroupBox1: TGroupBox;
    UseACubicLabel: TLabel;
    FlatMirrorLabel: TLabel;
    MapSizeLabel: TLabel;
    MapPeriodLabel: TLabel;
    GroupBox2: TGroupBox;
    BitmapNameLabel: TLabel;
    StrengthLabel: TLabel;
    TilingLabel: TLabel;
    AlphaLabel: TLabel;
    FilterLabel: TLabel;
    BlurLabel: TLabel;
    MirrorLabel: TLabel;
    NegativeLabel: TLabel;
    UScaleLabel: TLabel;
    VScaleLabel: TLabel;
    UOffsetLabel: TLabel;
    VOffsetLabel: TLabel;
    RotationLabel: TLabel;
    SourceLabel: TLabel;
    Tint1Label: TLabel;
    Tint2Label: TLabel;
    RedTintLabel: TLabel;
    GreenTintLabel: TLabel;
    BlueTintLabel: TLabel;
    DataSizeLabel: TLabel;
    DataLabel: TLabel;
    Tint1Shape: TShape;
    Tint2Shape: TShape;
    RedTintShape: TShape;
    GreenTintShape: TShape;
    BlueTIntShape: TShape;
    procedure FormHide(Sender: TObject);
  private
    function ConvertColor(const Color: TFColor3DS): String;
    function ConvertColor2(const Color: TFColor3DS): TColor;
    { Private declarations }
  public
    procedure Show(MapName: String; Map, Mask: PBitmap3DS; RMap: Boolean; UseAuto: Boolean = False; AutoMap: PACubic3DS = nil); reintroduce; 
  end;

var
  BitmapForm: TBitmapForm;

//---------------------------------------------------------------------------------------------------------------------

implementation

{$R *.DFM}

uses Main;

//---------------------------------------------------------------------------------------------------------------------

function TBitmapForm.ConvertColor(const Color: TFColor3DS): String;

begin
  Result := Format('red: %d; green: %d; blue: %d', [Round(Color.R * 255), Round(Color.G * 255), Round(Color.B * 255)]);
end;

//---------------------------------------------------------------------------------------------------------------------

function TBitmapForm.ConvertColor2(const Color: TFColor3DS): TColor;

begin
  Result := RGB(Round(Color.R * 255), Round(Color.G * 255), Round(Color.B * 255));
end;

//---------------------------------------------------------------------------------------------------------------------

procedure TBitmapForm.Show(MapName: String; Map, Mask: PBitmap3DS; RMap: Boolean; UseAuto: Boolean = False; AutoMap: PACubic3DS = nil);

const TileToString: array[TTileType3DS] of String = ('tile', 'decal', 'tiling and decal');
      TintToString: array[TTintType3DS] of String = ('RGB', 'Alpha', 'RGB luma tint', 'Alpha tint', 'RGB tint');

begin
  // special case reflection map:
  if RMap then
    with Automap^ do
    begin
      with UseACubicLabel do
      begin
        Enabled := True;
        if UseAuto then Caption := 'automapping is active'
                   else Caption := 'automapping not used';
      end;
      with FlatMirrorLabel do
      begin
        Enabled := True;
        if Flat then Caption := 'flat mirror reflection used'
                else Caption := 'flat mirror reflection not used';
      end;
      with MapSizeLabel do
      begin
        Enabled := True;
        Caption := Format('Map resolution: %d', [Size]);
      end;
      with MapPeriodLabel do
      begin
        Enabled := True;
        Caption := Format('Map update period: %d', [nthFrame]);
      end;
    end
    else
    begin
      with UseACubicLabel do begin Caption := 'Use automap: ?'; Enabled := False; end;
      with FlatMirrorLabel do begin Caption := 'Flat mirror reflection: ?'; Enabled := False; end;
      with MapSizeLabel do begin Caption := 'Map resolution: ?'; Enabled := False; end;
      with MapPeriodLabel do begin Caption := 'Map update period: ?'; Enabled := False; end;
    end;

  // bitmap settings
  with Map^ do
  begin
    BitmapNameLabel.Caption := 'Bitmap Name: ' + Name;
    StrengthLabel.Caption := Format('Strength: %d%%', [Round(Percent * 100)]);  
    TilingLabel.Caption := 'Tiling type: ' + TileToString[Tiling];
    if IgnoreAlpha then AlphaLabel.Caption := 'Alpha is ignored'
                   else AlphaLabel.Caption := 'Alpha is not ignored';
    if Filter = ftPyramidal then FilterLabel.Caption := 'Pyramidal filter is used'
                            else FilterLabel.Caption := 'Summed area filter is used';
    BlurLabel.Caption := Format('Blur: %f', [Blur]);
    if Mirror then MirrorLabel.Caption := 'Mirroring is active'
              else MirrorLabel.Caption := 'Mirroring is not active';
    if Negative then NegativeLabel.Caption := 'Negative is used'
                else NegativeLabel.Caption := 'Negative is not used';
    UScaleLabel.Caption := Format('U scale: %f', [UScale]);
    VScaleLabel.Caption := Format('V scale: %f', [VScale]);
    UOffsetLabel.Caption := Format('U offset: %f', [UOffset]);
    VOffsetLabel.Caption := Format('V offset: %f', [VOffset]);
    RotationLabel.Caption := Format('Rotation: %f', [Rotation]);
    SourceLabel.Caption := 'Source: ' + TintToString[SOurce];
    Tint1Label.Caption := 'Tint 1: ' + ConvertColor(Tint1);
    with Tint1Shape do
    begin
      Brush.Color := ConvertColor2(Tint1);
      Brush.Style := bsSolid;
    end;

    Tint2Label.Caption := 'Tint 2:' + ConvertColor(Tint2);
    with Tint2Shape do
    begin
      Brush.Color := ConvertColor2(Tint2);
      Brush.Style := bsSolid;
    end;

    RedTintLabel.Caption := 'Red tint:' + ConvertColor(RedTint);
    with RedTintShape do
    begin
      Brush.Color := ConvertColor2(RedTint);
      Brush.Style := bsSolid;
    end;

    GreenTintLabel.Caption := 'Green tint:' + ConvertColor(GreenTint);
    with GreenTintShape do
    begin
      Brush.Color := ConvertColor2(GreenTint);
      Brush.Style := bsSolid;
    end;

    BlueTintLabel.Caption := 'Blue tint:' + ConvertColor(BlueTint);
    with BlueTintShape do
    begin
      Brush.Color := ConvertColor2(BlueTint);
      Brush.Style := bsSolid;
    end;

    DataSizeLabel.Caption := Format('Data size: %d', [DataSize]);
    DataLabel.Caption := Format('Data pointer: $%p', [Data]);
  end;

  if not visible then inherited Show;
end;

//---------------------------------------------------------------------------------------------------------------------

procedure TBitmapForm.FormHide(Sender: TObject);

begin
  // when the viewer is going to be hidden then all mesh settings button should be set to "unpressed"
  with MainForm.SpeedButton1 do begin Down := True; Down := False; end;
end;

//---------------------------------------------------------------------------------------------------------------------

end.
